
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __GST_ENUM_TYPES_H__
#define __GST_ENUM_TYPES_H__

#include <glib-object.h>
#include <gst/validate/validate.h>
#include <gst/validate/media-descriptor-writer.h>

G_BEGIN_DECLS

/* enumerations from "gst-validate-enums.h" */
GST_VALIDATE_API GType gst_validate_reporting_details_get_type (void);
#define GST_TYPE_VALIDATE_REPORTING_DETAILS (gst_validate_reporting_details_get_type ())
GST_VALIDATE_API GType gst_validate_verbosity_flags_get_type (void);
#define GST_TYPE_VALIDATE_VERBOSITY_FLAGS (gst_validate_verbosity_flags_get_type ())
GST_VALIDATE_API GType gst_validate_structure_resolve_variables_flags_get_type (void);
#define GST_TYPE_VALIDATE_STRUCTURE_RESOLVE_VARIABLES_FLAGS (gst_validate_structure_resolve_variables_flags_get_type ())
GST_VALIDATE_API GType gst_validate_object_set_property_flags_get_type (void);
#define GST_TYPE_VALIDATE_OBJECT_SET_PROPERTY_FLAGS (gst_validate_object_set_property_flags_get_type ())

/* enumerations from "gst-validate-report.h" */
GST_VALIDATE_API GType gst_validate_debug_flags_get_type (void);
#define GST_TYPE_VALIDATE_DEBUG_FLAGS (gst_validate_debug_flags_get_type ())
GST_VALIDATE_API GType gst_validate_report_level_get_type (void);
#define GST_TYPE_VALIDATE_REPORT_LEVEL (gst_validate_report_level_get_type ())
GST_VALIDATE_API GType gst_validate_issue_flags_get_type (void);
#define GST_TYPE_VALIDATE_ISSUE_FLAGS (gst_validate_issue_flags_get_type ())

/* enumerations from "gst-validate-reporter.h" */
GST_VALIDATE_API GType gst_validate_interception_return_get_type (void);
#define GST_TYPE_VALIDATE_INTERCEPTION_RETURN (gst_validate_interception_return_get_type ())

/* enumerations from "gst-validate-scenario.h" */
GST_VALIDATE_API GType gst_validate_action_return_get_type (void);
#define GST_TYPE_VALIDATE_ACTION_RETURN (gst_validate_action_return_get_type ())
GST_VALIDATE_API GType gst_validate_action_type_flags_get_type (void);
#define GST_TYPE_VALIDATE_ACTION_TYPE_FLAGS (gst_validate_action_type_flags_get_type ())

/* enumerations from "media-descriptor-writer.h" */
GST_VALIDATE_API GType gst_validate_media_descriptor_writer_flags_get_type (void);
#define GST_TYPE_VALIDATE_MEDIA_DESCRIPTOR_WRITER_FLAGS (gst_validate_media_descriptor_writer_flags_get_type ())
G_END_DECLS

#endif /* __GST_ENUM_TYPES_H__ */

/* Generated data ends here */

